==> scala_2.5.0.orig.tar.gz: scala-2.5.0-final/src/library/scala/compat/Math.scala <==
/*                     __                                               *\
**     ________ ___   / /  ___     Scala API                            **
**    / __/ __// _ | / /  / _ |    (c) 2002-2006, LAMP/EPFL             **
**  __\ \/ /__/ __ |/ /__/ __ |                                         **
** /____/\___/_/ |_/____/_/ | |                                         **
**                          |/                                          **
\*                                                                      */

// $Id: Math.scala 10799 2007-04-24 15:56:55Z mihaylov $


package scala.compat;

/**
 * This class will be removed soon. Use scala.Math instead
 */
@deprecated
object Math {
  val MIN_BYTE   = java.lang.Byte.MIN_VALUE
  val MAX_BYTE   = java.lang.Byte.MAX_VALUE
  val MIN_SHORT  = java.lang.Short.MIN_VALUE
  val MAX_SHORT  = java.lang.Short.MAX_VALUE
  val MIN_CHAR   = java.lang.Character.MIN_VALUE
  val MAX_CHAR   = java.lang.Character.MAX_VALUE
  val MIN_INT    = java.lang.Integer.MIN_VALUE
  val MAX_INT    = java.lang.Integer.MAX_VALUE
  val MIN_LONG   = java.lang.Long.MIN_VALUE
  val MAX_LONG   = java.lang.Long.MAX_VALUE

  val MIN_FLOAT  = -java.lang.Float.MAX_VALUE
  val EPS_FLOAT  = java.lang.Float.MIN_VALUE
  val MAX_FLOAT  = java.lang.Float.MAX_VALUE
  val NaN_FLOAT  = java.lang.Float.NaN
  val NEG_INF_FLOAT = java.lang.Float.NEGATIVE_INFINITY
  val POS_INF_FLOAT = java.lang.Float.POSITIVE_INFINITY

  val MIN_DOUBLE = -java.lang.Double.MAX_VALUE
  val EPS_DOUBLE = java.lang.Double.MIN_VALUE
  val MAX_DOUBLE = java.lang.Double.MAX_VALUE
  val NaN_DOUBLE = java.lang.Double.NaN
  val NEG_INF_DOUBLE = java.lang.Double.NEGATIVE_INFINITY
  val POS_INF_DOUBLE = java.lang.Double.POSITIVE_INFINITY

  val E = java.lang.Math.E
  val PI = java.lang.Math.PI

  def min(x: Int, y: Int): Int = java.lang.Math.min(x, y)
  def max(x: Int, y: Int): Int = java.lang.Math.max(x, y)

  def ceil (x: Double): Double = java.lang.Math.ceil(x)
  def floor(x: Double): Double = java.lang.Math.floor(x)
  def log  (x: Double): Double = java.lang.Math.log(x)
  def sqrt (x: Double): Double = java.lang.Math.sqrt(x)
}

==> scala_2.6.1.orig.tar.gz: scala-2.6.1-final/src/library/scala/compat/Math.scala <==
/*                     __                                               *\
**     ________ ___   / /  ___     Scala API                            **
**    / __/ __// _ | / /  / _ |    (c) 2002-2007, LAMP/EPFL             **
**  __\ \/ /__/ __ |/ /__/ __ |    http://scala-lang.org/               **
** /____/\___/_/ |_/____/_/ | |                                         **
**                          |/                                          **
\*                                                                      */

// $Id: Math.scala 12292 2007-07-12 17:05:58Z michelou $


package scala.compat

/**
 * This class will be removed soon. Use <code>scala.Math</code> instead.
 */
@deprecated
object Math {
  val MIN_BYTE   = java.lang.Byte.MIN_VALUE
  val MAX_BYTE   = java.lang.Byte.MAX_VALUE
  val MIN_SHORT  = java.lang.Short.MIN_VALUE
  val MAX_SHORT  = java.lang.Short.MAX_VALUE
  val MIN_CHAR   = java.lang.Character.MIN_VALUE
  val MAX_CHAR   = java.lang.Character.MAX_VALUE
  val MIN_INT    = java.lang.Integer.MIN_VALUE
  val MAX_INT    = java.lang.Integer.MAX_VALUE
  val MIN_LONG   = java.lang.Long.MIN_VALUE
  val MAX_LONG   = java.lang.Long.MAX_VALUE

  val MIN_FLOAT  = -java.lang.Float.MAX_VALUE
  val EPS_FLOAT  = java.lang.Float.MIN_VALUE
  val MAX_FLOAT  = java.lang.Float.MAX_VALUE
  val NaN_FLOAT  = java.lang.Float.NaN
  val NEG_INF_FLOAT = java.lang.Float.NEGATIVE_INFINITY
  val POS_INF_FLOAT = java.lang.Float.POSITIVE_INFINITY

  val MIN_DOUBLE = -java.lang.Double.MAX_VALUE
  val EPS_DOUBLE = java.lang.Double.MIN_VALUE
  val MAX_DOUBLE = java.lang.Double.MAX_VALUE
  val NaN_DOUBLE = java.lang.Double.NaN
  val NEG_INF_DOUBLE = java.lang.Double.NEGATIVE_INFINITY
  val POS_INF_DOUBLE = java.lang.Double.POSITIVE_INFINITY

  val E = java.lang.Math.E
  val PI = java.lang.Math.PI

  def min(x: Int, y: Int): Int = java.lang.Math.min(x, y)
  def max(x: Int, y: Int): Int = java.lang.Math.max(x, y)

  def ceil (x: Double): Double = java.lang.Math.ceil(x)
  def floor(x: Double): Double = java.lang.Math.floor(x)
  def log  (x: Double): Double = java.lang.Math.log(x)
  def sqrt (x: Double): Double = java.lang.Math.sqrt(x)
}
